
RELEASE_VERSION='0.0.415464198'
BUILD_DATE='Wed Nov 24 14:27:58 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-t4krtqay-project-28359933-concurrent-02hgvx 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1815281308'
GIT_COMMIT_SHA='364eaca79200b0b999391c9acccd1d301daa5297'
GIT_BRANCH='main'
